#!/usr/bin/env python3
"""
HTTP Header Checker
Parameters:
    - IP: Target IP address
    - port: Target port number (default: 80)
"""
import http.client
import argparse
import ssl

def check_headers(ip, port):
    try:
        if port == 443:
            conn = http.client.HTTPSConnection(ip, port, context=ssl._create_unverified_context())
        else:
            conn = http.client.HTTPConnection(ip, port)
        
        conn.request("HEAD", "/")
        response = conn.getresponse()
        
        print(f"Status: {response.status} {response.reason}")
        print("\nHeaders:")
        for header, value in response.getheaders():
            print(f"{header}: {value}")
            
        conn.close()
    except Exception as e:
        print(f"Error: {str(e)}")

if __name__ == "__main__":
    parser = argparse.ArgumentParser(description="HTTP Header Checker")
    parser.add_argument("ip", help="Target IP address")
    parser.add_argument("--port", type=int, default=80, help="Target port number (default: 80)")
    args = parser.parse_args()
    
    check_headers(args.ip, args.port)
